#ifndef OIDC_AGENT_OIDCUTILS_H
#define OIDC_AGENT_OIDCUTILS_H

char* removeScope(char* scopes, const char* rem);

#endif  // OIDC_AGENT_OIDCUTILS_H
